@@ -90,7 +90,7 @@ __PACKAGE__->set_primary_key("attribute_values_id");
 
 =head1 RELATIONS
 
-=head2 Attribute
+=head2 attribute
 
 Type: belongs_to
 
@@ -99,13 +99,13 @@ Related object: L<Interchange6::Schema::Result::Attribute>
 =cut
 
 __PACKAGE__->belongs_to(
-  "Attribute",
+  "attribute",
   "Interchange6::Schema::Result::Attribute",
   { attributes_id => "attributes_id" },
   { is_deferrable => 1, on_delete => "CASCADE", on_update => "CASCADE" },
 );
 
-=head2 ProductAttributeValue
+=head2 product_attribute_values
 
 Type: has_many
 
@@ -114,13 +114,13 @@ Related object: L<Interchange6::Schema::Result::ProductAttributeValue>
 =cut
 
 __PACKAGE__->has_many(
-  "ProductAttributeValue",
+  "product_attribute_values",
   "Interchange6::Schema::Result::ProductAttributeValue",
   { "foreign.attribute_values_id" => "self.attribute_values_id" },
   { cascade_copy => 0, cascade_delete => 0 },
 );
 
-=head2 UserAttributeValue
+=head2 user_attribute_values
 
 Type: has_many
 
@@ -129,13 +129,13 @@ Related object: L<Interchange6::Schema::Result::UserAttributeValue>
 =cut
 
 __PACKAGE__->has_many(
-  "UserAttributeValue",
+  "user_attribute_values",
   "Interchange6::Schema::Result::UserAttributeValue",
   { "foreign.attribute_values_id" => "self.attribute_values_id" },
   { cascade_copy => 0, cascade_delete => 0 },
 );
 
-=head2 NavigationAttributeValue
+=head2 navigation_attribute_values
 
 Type: has_many
 
@@ -144,7 +144,7 @@ Related object: L<Interchange6::Schema::Result::NavigationAttributeValue>
 =cut
 
 __PACKAGE__->has_many(
-  "NavigationAttributeValue",
+  "navigation_attribute_values",
   "Interchange6::Schema::Result::NavigationAttributeValue",
   { "foreign.attribute_values_id" => "self.attribute_values_id" },
   { cascade_copy => 0, cascade_delete => 0 },
