@@ -24,7 +24,7 @@ B<scope:> Internal sorting field.
 
 B<country_iso_code:> Two letter country code such as 'SI' = Slovenia.
 
-<state_iso_code:> Alpha state code such as 'NY' = New York.
+B<state_iso_code:> Alpha state code such as 'NY' = New York.
 
 B<name:>  Full state name.
 
