@@ -60,7 +60,13 @@ sub expire {
         }
     );
 
-     while (my $session_rs = $session->next) {
+    while (my $session_rs = $session->next) {
+        # check for payment orders with this session
+        my $po_rs = $session_rs->search_related('payment_orders');
+        while (my $po = $po_rs->next) {
+            $po->update({ sessions_id => undef });
+        }
+        # check for carts with this session
         my $cart_rs = $session_rs->search_related('carts');
         while (my $cart = $cart_rs->next) {
             my $user_id = $cart->users_id;
