@@ -1,6 +1,6 @@
 package Test::Media;
 
-use Test::Exception;
+use Test::Most;
 use Test::Roo::Role;
 
 test 'media tests' => sub {
@@ -11,7 +11,7 @@ test 'media tests' => sub {
 
     my $ret;
 
-    my $schema = $self->ic6s_schema;
+    my $schema = $self->schema;
 
     my %product_data = (
         sku               => 'G000X',
